==> haskell-shelly-1.8.1-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shelly
version: 1.8.1
id: shelly-1.8.1-FudTMGLI0ah7TKsQ9CxowZ
key: shelly-1.8.1-FudTMGLI0ah7TKsQ9CxowZ
license: BSD-3-Clause
maintainer: Greg Weber <greg@gregweber.info>
author: Greg Weber, Petr Rockai
homepage: https://github.com/yesodweb/Shelly.hs
synopsis: shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:
    .
    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance.
    .
    * has detailed and useful error messages
    .
    * maintains its own environment, making it thread-safe.
    .
    * is modern, using Text and system-filepath/system-fileio
    .
    Shelly is originally forked from the Shellish package.
    .
    See the shelly-extra package for additional functionality.
    .
    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>
category: Development
abi: 7625894cd80be45a354ee07f216e86ee
exposed: True
exposed-modules:
    Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules: Shelly.Base Shelly.Find Shelly.Directory
import-dirs: /usr/lib/ghc-8.4.3/site-local/shelly-1.8.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/shelly-1.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/shelly-1.8.1
hs-libraries: HSshelly-1.8.1-FudTMGLI0ah7TKsQ9CxowZ
depends:
    containers-0.5.11.0 time-1.8.0.2 directory-1.3.1.5 mtl-2.2.2
    process-1.6.3.0 unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj
    unix-2.7.2.2 system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4
    system-fileio-0.3.16.4-9sx9wM2ewcAGE6Edeaomm
    monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX
    lifted-base-0.2.3.12-4z1u4fqVS2e1krf2z3g8tM
    lifted-async-0.10.0.2-KxbSMLWSVn2IuAvlc5XaT1
    exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi
    enclosed-exceptions-1.0.3-9lY4zNxYanG1uBO73DvhGW text-1.2.3.0
    bytestring-0.10.8.2 async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    transformers-0.5.5.0
    transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh base-4.11.1.0
abi-depends: containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj=2a0e42b97373c43e88dbd8b7b82c7192
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=14adf804eb2ee22bef25db71be916c66
             system-fileio-0.3.16.4-9sx9wM2ewcAGE6Edeaomm=37c2c7ce65c654ffd5891288a911d53a
             monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX=ccfd06c57089143c2e021ca11cc4fff5
             lifted-base-0.2.3.12-4z1u4fqVS2e1krf2z3g8tM=d7abf1639edb70a4973bc923dc291932
             lifted-async-0.10.0.2-KxbSMLWSVn2IuAvlc5XaT1=0de9fe83cfdafd0b3f86e85bb1618528
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             enclosed-exceptions-1.0.3-9lY4zNxYanG1uBO73DvhGW=7a398a87e93ccc2c1fcded9e16edc174
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh=24d243b13204b0d99b0f7fc5f56cecfb
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html: /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shelly-1.8.1-25-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-shelly.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shelly
version: 1.8.1
id: shelly-1.8.1-I7OsaFBMhqo3EFvFziNLSr
key: shelly-1.8.1-I7OsaFBMhqo3EFvFziNLSr
license: BSD-3-Clause
maintainer: Greg Weber <greg@gregweber.info>
author: Greg Weber, Petr Rockai
homepage: https://github.com/yesodweb/Shelly.hs
synopsis: shell-like (systems) programming in Haskell
description:
    Shelly provides convenient systems programming in Haskell,
    similar in spirit to POSIX shells. Shelly:
    .
    * is aimed at convenience and getting things done rather than
    being a demonstration of elegance.
    .
    * has detailed and useful error messages
    .
    * maintains its own environment, making it thread-safe.
    .
    * is modern, using Text and system-filepath/system-fileio
    .
    Shelly is originally forked from the Shellish package.
    .
    See the shelly-extra package for additional functionality.
    .
    An overview is available in the README: <https://github.com/yesodweb/Shelly.hs/blob/master/README.md>
category: Development
abi: 25a41d7b68d94d063a36f44ff9da0076
exposed: True
exposed-modules:
    Shelly Shelly.Lifted Shelly.Pipe Shelly.Unix
hidden-modules: Shelly.Base Shelly.Find Shelly.Directory
import-dirs: /usr/lib/ghc-8.4.3/site-local/shelly-1.8.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/shelly-1.8.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/shelly-1.8.1
hs-libraries: HSshelly-1.8.1-I7OsaFBMhqo3EFvFziNLSr
depends:
    containers-0.5.11.0 time-1.8.0.2 directory-1.3.1.5 mtl-2.2.2
    process-1.6.3.0 unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj
    unix-2.7.2.2 system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4
    system-fileio-0.3.16.4-9sx9wM2ewcAGE6Edeaomm
    monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX
    lifted-base-0.2.3.12-4z1u4fqVS2e1krf2z3g8tM
    lifted-async-0.10.0.3-K8q4pkB6MowHVgMq1mbTKe
    exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi
    enclosed-exceptions-1.0.3-9lY4zNxYanG1uBO73DvhGW text-1.2.3.0
    bytestring-0.10.8.2 async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    transformers-0.5.5.0
    transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh base-4.11.1.0
abi-depends: containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             unix-compat-0.5.1-IZ2l0C7CE13FdrCF8rJfBj=2a0e42b97373c43e88dbd8b7b82c7192
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
             system-filepath-0.4.14-9jYDOZRDoMqIkxdisSNvm4=14adf804eb2ee22bef25db71be916c66
             system-fileio-0.3.16.4-9sx9wM2ewcAGE6Edeaomm=37c2c7ce65c654ffd5891288a911d53a
             monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX=ccfd06c57089143c2e021ca11cc4fff5
             lifted-base-0.2.3.12-4z1u4fqVS2e1krf2z3g8tM=d7abf1639edb70a4973bc923dc291932
             lifted-async-0.10.0.3-K8q4pkB6MowHVgMq1mbTKe=d51df98647312c514c7b5021c1f73282
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             enclosed-exceptions-1.0.3-9lY4zNxYanG1uBO73DvhGW=7a398a87e93ccc2c1fcded9e16edc174
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh=24d243b13204b0d99b0f7fc5f56cecfb
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-shelly/html/shelly.haddock
haddock-html: /usr/share/doc/haskell-shelly/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
